@@ -1,14 +1,19 @@
 #!/usr/bin/python2.5
 
-# Copyright (c) 2010 Christos Zamantzas
+# Copyright (c) 2011 Christos Zamantzas
 # Licenced under GPLv2
 
-#######################################################################
-##  CSSUfeatures  -  Configuration UI for the Community SSU features ##
-#######################################################################
+########################################################################
+## CSSU Features Configuration 
+##
+## Configuration UI for the Community SSU features
+## for info on the features it provides access see: 
+## http://wiki.maemo.org/Community_SSU/Features
+########################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-Version = '1.1-1'
+
+Version = '1.2-1'
 
 import os
 import sys
@@ -19,7 +24,7 @@ from PyQt4.QtCore import *
 from PyQt4.QtMaemo5 import *
 from CSSUfeaturesUI import *
 
-##############################################################
+#############################################################################################################
 
 PathApp             = '/opt/CSSUfeatures'             # application path
 PathSystem          = '/usr/share/hildon-desktop/'    # main path
@@ -30,9 +35,9 @@ PathTemp            = '/home/user/.CSSUfeatures/'     # temp path of files
 ConfigTempSystem    = 'CSSUfeatures_temp_system'      # name of temp config file from/for system
 ConfigTempTheme     = 'CSSUfeatures_temp_theme'       # name of temp config file from/for theme
 
-##############################################################
+#############################################################################################################
 
-def CheckFile(Path, File):       
+def checkFile(Path, File):       
     ''' Check if a file exists. '''
 
     try:
@@ -59,14 +64,14 @@ def showQuickMessage(message):
                org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
-def CheckConfigFile():
+def checkConfigFile():
      ''' Check for configulation files. '''               
 
      global Path, PathSystem
-     if CheckFile(PathTheme,ConfigTheme) == True:
+     if checkFile(PathTheme,ConfigTheme) == True:
          Path = PathTheme
          Config = ConfigTheme
-     elif CheckFile(PathSystem,ConfigSystem) == True:
+     elif checkFile(PathSystem,ConfigSystem) == True:
          Path = PathSystem
          Config = ConfigSystem
      else:
@@ -74,9 +79,29 @@ def CheckConfigFile():
          showMessage(message)
          sys.exit(1)
 
-def getCurrent():   
+def checkCSSUinstalled():
+     '''Check if the CSSU is installed in the system'''
+     
+     time.sleep(1)
+     if os.popen('if dpkg -l | grep mp-fremantle-community-pr 1>/dev/null; then echo $?;fi').read() == '0\n':
+         return True
+     else: 
+         return False
 
-     if CheckFile(PathTheme,ConfigTheme) == True:
+def checkTactileInstalled():
+     '''Check if the Tactile package is installed in the system'''
+     
+     time.sleep(1)
+     if os.popen('if dpkg -l | grep tactile 1>/dev/null; then echo $?;fi').read() == '0\n':
+         return True
+     else: 
+         return False
+
+         
+def getCurrent():   
+     '''Read the values currently in the config file'''
+     
+     if checkFile(PathTheme,ConfigTheme) == True:
          Path = PathTheme
          Config = ConfigTheme
          message = 'INFO: Reading the configuration from a theme folder..'
@@ -107,8 +132,7 @@ def getCurrent():
          message = 'Reading the configuration settings gave a FATAL ERROR while loading\nSettings are corrupted.'
          showMessage(message)
          sys.exit(1)
-         
-             
+                   
 def doUpdateConfigSystem():            
     ''' Update the config file of the system with the edited. '''
 
@@ -138,7 +162,7 @@ class CSSUfeaturesAbout(QtGui.QMainWindow):
         self.parent = parent
         self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
         self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
-        self.setWindowTitle("CSSUfeatures About")
+        self.setWindowTitle("About CSSU Features Configuration")
 
         aboutScrollArea = QScrollArea(self)
         aboutScrollArea.setWidgetResizable(True)
@@ -230,9 +254,10 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
              QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
              QtCore.QObject.connect(self.ui.actionRestoreDefaults, QtCore.SIGNAL('triggered()'), self.doRestoreDefaults)
+             QtCore.QObject.connect(self.ui.actionRestartHildon, QtCore.SIGNAL('triggered()'), self.doRestartHildon)
              
              ## Check which config file to use.
-             CheckConfigFile()
+             checkConfigFile()
              ##Set current values in the GUI.
              self.doSetCurrent()
              
@@ -255,29 +280,46 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
                  message = 'The default transitions.ini file could not be restored to the system.'
              else: 
                  message = 'The default transitions.ini file have been restored to the system.\n\nINFO: Some of its settings will appear on the next reboot.'
-                 
-             showMessage(message)
              
+        def doRestartHildon(self):
+             '''Restart hildon for the settings to take effect.'''
+             
+             message = 'INFO: Hildon is being restarted..'
+             showQuickMessage(message)
+             
+             os.system('sudo %s/updateTransitions restartHildon' % PathApp)
+            
         def doSetCurrent(self):
              ''' Set CURRENT values in the GUI''' 
 
              #Get the values from the configuration file.
              getCurrent()
+             
+             ##Check if the tactile package is installed
+             if checkTactileInstalled() == False:
+                 self.ui.comboBoxTactile.setEnabled(False)
+             else:
+                 pass
 
              #Set them in the GUI.
-             self.ui.comboBoxZoomPress.setCurrentIndex(int(dataVars['zoom_on_press']))
-             self.ui.comboBoxBlurless.setCurrentIndex(int(dataVars['blurless']))
-             self.ui.comboBoxTaskSwitcher.setCurrentIndex(int(dataVars['taskswitcher']))
-             self.ui.comboBoxRotationAxis.setCurrentIndex(int(dataVars['zaxisrotation']))
-             self.ui.comboBoxForcedRotation.setCurrentIndex(int(dataVars['forcerotation']))
-             self.ui.comboBoxTactile.setCurrentIndex(int(dataVars['tactilepopups']))
-             self.ui.lineEditParallax.setText(dataVars['parallax'])
-             
-             message = 'The CURRENT configuration options are shown.'
-             showQuickMessage(message)
+             try:
+                 self.ui.comboBoxZoomPress.setCurrentIndex(int(dataVars['zoom_on_press']))
+                 self.ui.comboBoxBlurless.setCurrentIndex(int(dataVars['blurless']))
+                 self.ui.comboBoxTaskSwitcher.setCurrentIndex(int(dataVars['taskswitcher']))
+                 self.ui.comboBoxRotationAxis.setCurrentIndex(int(dataVars['zaxisrotation']))
+                 self.ui.comboBoxForcedRotation.setCurrentIndex(int(dataVars['forcerotation']))
+                 self.ui.comboBoxTactile.setCurrentIndex(int(dataVars['tactilepopups']))
+                 self.ui.lineEditParallax.setText(dataVars['parallax'])
+                 
+                 message = 'The CURRENT configuration options are shown.'
+                 showQuickMessage(message)
+             except:
+                 message = 'Reading the configuration settings gave a FATAL ERROR while loading. Not all settings are available.\n\nExiting..'
+                 showMessage(message)
+                 sys.exit(1)
 
         def doSetDefault(self):  
-             ''' Set DEFAULT values in the GUI''' 
+             '''Set DEFAULT values in the GUI''' 
 
              self.ui.comboBoxBlurless.setCurrentIndex(0)
              self.ui.comboBoxTaskSwitcher.setCurrentIndex(0)
@@ -291,7 +333,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
              
         def doCreateConfig(self):        
-             ''' Create the new configuration file'''
+             '''Create the new configuration file'''
              
              message = 'Please wait. Update in progress..'
              showQuickMessage(message)
@@ -336,7 +378,7 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
              message = 'The new settings have been successfully saved.'
              
              #Update of the Theme config file (if it exists).
-             if CheckFile(PathTheme,ConfigTheme) == True:
+             if checkFile(PathTheme,ConfigTheme) == True:
 
                  os.rename( PathTemp + ConfigTempTheme, PathTemp + ConfigTempTheme + "~" )
                  destination = open( PathTemp + ConfigTempTheme, "w" )
@@ -366,31 +408,41 @@ class CSSUfeaturesMainWindow(QtGui.QMainWindow):
 
              showMessage(message)
 
-class CSSUfeaturesMain():             
-#if __name__ == "__main__":
+class CSSUfeaturesMain(): 
      
-    ##Check with what priviledges the GUI has been executed
-    if os.geteuid() == 0:
-        message ='ERROR: The CSSU Features Configuration application cannot be executed as root. Exiting..'
-        showMessage(message)
-        sys.exit(1)
-
-    ##Check if temp folder is available
-    if os.path.exists(PathTemp) == False:
-        os.system('mkdir %s' % PathTemp)
-    else:
-        pass
-    
-    os.system('cp %s %s' % (PathSystem + ConfigSystem, PathTemp + ConfigTempSystem))
-    if CheckFile(PathTheme,ConfigTheme) == True: 
-        os.system('cp %s %s' % (PathTheme + ConfigTheme, PathTemp + ConfigTempTheme))
-        message = 'INFO: The application found a settings file in the theme folder.\nThe application will update both system and theme files with any changes requested.'
-        showMessage(message)
-    else:
-        pass
-        
-    ##Open Dialog Window
-    app = QtGui.QApplication(sys.argv)
-    myapp = CSSUfeaturesMainWindow()
-    myapp.show()
-    sys.exit(app.exec_())
\ No newline at end of file
+     ##Check with what priviledges the GUI has been executed
+     if os.geteuid() == 0:
+         message = 'ERROR: The CSSU Features Configuration application cannot be executed as root. Exiting..'
+         showMessage(message)
+         sys.exit(1)
+     else:
+         pass
+     
+     ##Check if CSSU is installed
+     if checkCSSUinstalled() == False:
+         message = 'ERROR: The Community SSU is not installed.\n\nExiting..'
+         showMessage(message)
+         sys.exit(1)
+     else:
+         pass
+     
+     ##Check if temp folder is available
+     if os.path.exists(PathTemp) == False:
+         os.system('mkdir %s' % PathTemp)
+     else:
+         pass
+     
+     ##Copy the system/theme congiguration files for later editing
+     os.system('cp %s %s' % (PathSystem + ConfigSystem, PathTemp + ConfigTempSystem))
+     if checkFile(PathTheme,ConfigTheme) == True: 
+         os.system('cp %s %s' % (PathTheme + ConfigTheme, PathTemp + ConfigTempTheme))
+         message = 'INFO: The application found a settings file in the theme folder.\nThe application will update both system and theme files with any changes requested.'
+         showMessage(message)
+     else:
+         pass
+     
+     ##Open Dialog Window
+     app = QtGui.QApplication(sys.argv)
+     myapp = CSSUfeaturesMainWindow()
+     myapp.show()
+     sys.exit(app.exec_())
\ No newline at end of file
